@@ -19,7 +19,9 @@
     Sam Lantinga
     slouken@libsdl.org
 */
+#include "SDL_config.h"
 
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 
 typedef HANDLE SYS_ThreadHandle;
